[patch 32/47] x86: ioapic: Clean up the direct access to irq_desc

Previous message: [thread] [date] [author]
Next message: [thread] [date] [author]
From: Thomas Gleixner
Date: Thursday, September 30, 2010 - 4:17 pm

Most of it is useless pseudo optimization.

Signed-off-by: Thomas Gleixner <tglx@linutronix.de>
---
 arch/x86/kernel/apic/io_apic.c |   81 ++++++++++++++---------------------------
 1 file changed, 29 insertions(+), 52 deletions(-)

Index: linux-2.6-tip/arch/x86/kernel/apic/io_apic.c
===================================================================
--- linux-2.6-tip.orig/arch/x86/kernel/apic/io_apic.c
+++ linux-2.6-tip/arch/x86/kernel/apic/io_apic.c
@@ -150,10 +150,7 @@ static struct irq_cfg irq_cfgx[NR_IRQS];
 int __init arch_early_irq_init(void)
 {
 	struct irq_cfg *cfg;
-	struct irq_desc *desc;
-	int count;
-	int node;
-	int i;
+	int count, node, i;
 
 	if (!legacy_pic->nr_legacy_irqs) {
 		nr_irqs_gsi = 0;
@@ -162,11 +159,10 @@ int __init arch_early_irq_init(void)
 
 	cfg = irq_cfgx;
 	count = ARRAY_SIZE(irq_cfgx);
-	node= cpu_to_node(boot_cpu_id);
+	node = cpu_to_node(boot_cpu_id);
 
 	for (i = 0; i < count; i++) {
-		desc = irq_to_desc(i);
-		set_irq_desc_chip_data(desc, &cfg[i]);
+		set_irq_chip_data(i, &cfg[i]);
 		zalloc_cpumask_var_node(&cfg[i].domain, GFP_NOWAIT, node);
 		zalloc_cpumask_var_node(&cfg[i].old_domain, GFP_NOWAIT, node);
 		/*
@@ -185,14 +181,7 @@ int __init arch_early_irq_init(void)
 #ifdef CONFIG_SPARSE_IRQ
 struct irq_cfg *irq_cfg(unsigned int irq)
 {
-	struct irq_cfg *cfg = NULL;
-	struct irq_desc *desc;
-
-	desc = irq_to_desc(irq);
-	if (desc)
-		cfg = get_irq_desc_chip_data(desc);
-
-	return cfg;
+	return get_irq_chip_data(irq);
 }
 
 static struct irq_cfg *get_one_free_irq_cfg(int node)
@@ -1316,17 +1305,17 @@ static inline int IO_APIC_irq_trigger(in
 }
 #endif
 
-static void ioapic_register_intr(int irq, struct irq_desc *desc, unsigned long trigger)
+static void ioapic_register_intr(unsigned int irq, unsigned long trigger)
 {
 
 	if ((trigger == IOAPIC_AUTO && IO_APIC_irq_trigger(irq)) ||
 	    trigger == IOAPIC_LEVEL)
-		desc->status |= IRQ_LEVEL;
+		irq_set_status_flags(irq, IRQ_LEVEL);
 	else
-		desc->status &= ~IRQ_LEVEL;
+		irq_clear_status_flags(irq, IRQ_LEVEL);
 
 	if (irq_remapped(irq)) {
-		desc->status |= IRQ_MOVE_PCNTXT;
+		irq_set_status_flags(irq, IRQ_MOVE_PCNTXT);
 		if (trigger)
 			set_irq_chip_and_handler_name(irq, &ir_ioapic_chip,
 						      handle_fasteoi_irq,
@@ -1420,18 +1409,14 @@ int setup_ioapic_entry(int apic_id, int 
 	return 0;
 }
 
-static void setup_IO_APIC_irq(int apic_id, int pin, unsigned int irq, struct irq_desc *desc,
-			      int trigger, int polarity)
+static void setup_ioapic_irq(int apic_id, int pin, unsigned int irq,
+			     struct irq_cfg *cfg, int trigger, int polarity)
 {
-	struct irq_cfg *cfg;
 	struct IO_APIC_route_entry entry;
 	unsigned int dest;
 
 	if (!IO_APIC_IRQ(irq))
 		return;
-
-	cfg = get_irq_desc_chip_data(desc);
-
 	/*
 	 * For legacy irqs, cfg->domain starts with cpu 0 for legacy
 	 * controllers like 8259. Now that IO-APIC can handle this irq, update
@@ -1460,7 +1445,7 @@ static void setup_IO_APIC_irq(int apic_i
 		return;
 	}
 
-	ioapic_register_intr(irq, desc, trigger);
+	ioapic_register_intr(irq, trigger);
 	if (irq < legacy_pic->nr_legacy_irqs)
 		legacy_pic->mask(irq);
 
@@ -1525,8 +1510,8 @@ static void __init setup_IO_APIC_irqs(vo
 		 * don't mark it in pin_programmed, so later acpi could
 		 * set it correctly when irq < 16
 		 */
-		setup_IO_APIC_irq(apic_id, pin, irq, desc,
-				irq_trigger(idx), irq_polarity(idx));
+		setup_ioapic_irq(apic_id, pin, irq, cfg, irq_trigger(idx),
+				  irq_polarity(idx));
 	}
 
 	if (notcon)
@@ -1580,7 +1565,7 @@ void setup_IO_APIC_irq_extra(u32 gsi)
 	}
 	set_bit(pin, mp_ioapic_routing[apic_id].pin_programmed);
 
-	setup_IO_APIC_irq(apic_id, pin, irq, desc,
+	setup_ioapic_irq(apic_id, pin, irq, cfg,
 			irq_trigger(idx), irq_polarity(idx));
 }
 
@@ -2790,9 +2775,9 @@ static struct irq_chip lapic_chip __read
 	.irq_ack	= ack_lapic_irq,
 };
 
-static void lapic_register_intr(int irq, struct irq_desc *desc)
+static void lapic_register_intr(int irq)
 {
-	desc->status &= ~IRQ_LEVEL;
+	irq_clear_status_flags(irq, IRQ_LEVEL);
 	set_irq_chip_and_handler_name(irq, &lapic_chip, handle_edge_irq,
 				      "edge");
 }
@@ -2895,8 +2880,7 @@ int timer_through_8259 __initdata;
  */
 static inline void __init check_timer(void)
 {
-	struct irq_desc *desc = irq_to_desc(0);
-	struct irq_cfg *cfg = get_irq_desc_chip_data(desc);
+	struct irq_cfg *cfg = get_irq_chip_data(0);
 	int node = cpu_to_node(boot_cpu_id);
 	int apic1, pin1, apic2, pin2;
 	unsigned long flags;
@@ -2966,7 +2950,7 @@ static inline void __init check_timer(vo
 			add_pin_to_irq_node(cfg, node, apic1, pin1);
 			setup_timer_IRQ0_pin(apic1, pin1, cfg->vector);
 		} else {
 			/* for edge trigger, setup_IO_APIC_irq already
 			 * leave it unmasked.
 			 * so only need to unmask if it is level-trigger
 			 * do we really have level trigger timer?
@@ -3034,7 +3018,7 @@ static inline void __init check_timer(vo
 	apic_printk(APIC_QUIET, KERN_INFO
 		    "...trying to set up timer as Virtual Wire IRQ...\n");
 
-	lapic_register_intr(0, desc);
+	lapic_register_intr(0);
 	apic_write(APIC_LVT0, APIC_DM_FIXED | cfg->vector);	/* Fixed mode */
 	legacy_pic->unmask(0);
 
@@ -3478,8 +3462,8 @@ static int msi_alloc_irte(struct pci_dev
 
 static int setup_msi_irq(struct pci_dev *dev, struct msi_desc *msidesc, int irq)
 {
-	int ret;
 	struct msi_msg msg;
+	int ret;
 
 	ret = msi_compose_msg(dev, irq, &msg, -1);
 	if (ret < 0)
@@ -3489,11 +3473,7 @@ static int setup_msi_irq(struct pci_dev 
 	write_msi_msg(irq, &msg);
 
 	if (irq_remapped(irq)) {
-		struct irq_desc *desc = irq_to_desc(irq);
-		/*
-		 * irq migration in process context
-		 */
-		desc->status |= IRQ_MOVE_PCNTXT;
+		irq_set_status_flags(irq, IRQ_MOVE_PCNTXT);
 		set_irq_chip_and_handler_name(irq, &msi_ir_chip, handle_edge_irq, "edge");
 	} else
 		set_irq_chip_and_handler_name(irq, &msi_chip, handle_edge_irq, "edge");
@@ -3505,13 +3485,10 @@ static int setup_msi_irq(struct pci_dev 
 
 int arch_setup_msi_irqs(struct pci_dev *dev, int nvec, int type)
 {
-	unsigned int irq;
-	int ret, sub_handle;
+	int node, ret, sub_handle, index = 0;
+	unsigned int irq, irq_want;
 	struct msi_desc *msidesc;
-	unsigned int irq_want;
 	struct intel_iommu *iommu = NULL;
-	int index = 0;
-	int node;
 
 	/* x86 doesn't support multiple MSI yet */
 	if (type == PCI_CAP_ID_MSI && nvec > 1)
@@ -3697,7 +3674,7 @@ int arch_setup_hpet_msi(unsigned int irq
 		return ret;
 
 	hpet_msi_write(get_irq_data(irq), &msg);
-	irq_set_status_flags(irq,IRQ_MOVE_PCNTXT);
+	irq_set_status_flags(irq, IRQ_MOVE_PCNTXT);
 	if (irq_remapped(irq))
 		set_irq_chip_and_handler_name(irq, &ir_hpet_msi_type,
 					      handle_edge_irq, "edge");
@@ -3883,11 +3860,12 @@ static int __io_apic_set_pci_routing(str
 	trigger = irq_attr->trigger;
 	polarity = irq_attr->polarity;
 
+	cfg = get_irq_desc_chip_data(desc);
+
 	/*
 	 * IRQs < 16 are already in the irq_2_pin[] map
 	 */
 	if (irq >= legacy_pic->nr_legacy_irqs) {
-		cfg = get_irq_desc_chip_data(desc);
 		if (add_pin_to_irq_node_nopanic(cfg, node, ioapic, pin)) {
 			printk(KERN_INFO "can not add pin %d for irq %d\n",
 				pin, irq);
@@ -3895,7 +3873,7 @@ static int __io_apic_set_pci_routing(str
 		}
 	}
 
-	setup_IO_APIC_irq(ioapic, pin, irq, desc, trigger, polarity);
+	setup_ioapic_irq(ioapic, pin, irq, cfg, trigger, polarity);
 
 	return 0;
 }
@@ -4279,13 +4257,12 @@ void __init mp_register_ioapic(int id, u
 void __init pre_init_apic_IRQ0(void)
 {
 	struct irq_cfg *cfg;
-	struct irq_desc *desc;
 
 	printk(KERN_INFO "Early APIC setup for system timer0\n");
 #ifndef CONFIG_SMP
 	phys_cpu_present_map = physid_mask_of_physid(boot_cpu_physical_apicid);
 #endif
-	desc = irq_to_desc_alloc_node(0, 0);
+	irq_to_desc_alloc_node(0, 0);
 
 	setup_local_APIC();
 
@@ -4293,5 +4270,5 @@ void __init pre_init_apic_IRQ0(void)
 	add_pin_to_irq_node(cfg, 0, 0, 0);
 	set_irq_chip_and_handler_name(0, &ioapic_chip, handle_edge_irq, "edge");
 
-	setup_IO_APIC_irq(0, 0, 0, desc, 0, 0);
+	setup_ioapic_irq(0, 0, 0, cfg, 0, 0);
 }
@@ -2966,7 +2950,7 @@ static inline void __init check_timer(vo
 			setup_timer_IRQ0_pin(apic1, pin1, cfg->vector);
 		} else {
-			/* for edge trigger, setup_IO_APIC_irq already
+			/* for edge trigger, setup_ioapic_irq already
 			 * leave it unmasked.
 			 * so only need to unmask if it is level-trigger


--
Previous message: [thread] [date] [author]
Next message: [thread] [date] [author]

Messages in current thread:
[patch 00/47] Sparse irq rework, Thomas Gleixner, (Thu Sep 30, 4:14 pm)
[patch 01/47] x86: Plug memory leak in sparse irq, Thomas Gleixner, (Thu Sep 30, 4:14 pm)
[patch 03/47] genirq: Provide status modifier, Thomas Gleixner, (Thu Sep 30, 4:14 pm)
[patch 04/47] arm: Use irq status modifier, Thomas Gleixner, (Thu Sep 30, 4:14 pm)
[patch 05/47] genirq-sanitize-irq-data-accessors.patch, Thomas Gleixner, (Thu Sep 30, 4:14 pm)
[patch 06/47] genirq: Distangle kernel/irq/handle.c, Thomas Gleixner, (Thu Sep 30, 4:15 pm)
[patch 07/47] genirq: Remove early_init_irq_lock_class(), Thomas Gleixner, (Thu Sep 30, 4:15 pm)
[patch 08/47] genirq: Move core only inlines to kernel/irq, Thomas Gleixner, (Thu Sep 30, 4:15 pm)
[patch 10/47] genirq: Remove export of kstat_irqs_cpu, Thomas Gleixner, (Thu Sep 30, 4:15 pm)
[patch 11/47] genirq: Provide default irq init flags, Thomas Gleixner, (Thu Sep 30, 4:15 pm)
[patch 12/47] arm: Use ARCH_IRQ_INIT_FLAGS, Thomas Gleixner, (Thu Sep 30, 4:15 pm)
[patch 13/47] powerpc: Use ARCH_IRQ_INIT_FLAGS, Thomas Gleixner, (Thu Sep 30, 4:15 pm)
[patch 14/47] genirq: Implement a sane sparse_irq allocator, Thomas Gleixner, (Thu Sep 30, 4:15 pm)
[patch 16/47] genirq: Implement sane enumeration, Thomas Gleixner, (Thu Sep 30, 4:15 pm)
[patch 17/47] genirq-update-kerneldoc.patch, Thomas Gleixner, (Thu Sep 30, 4:15 pm)
[patch 18/47] genirq: Use sane sparse allocator, Thomas Gleixner, (Thu Sep 30, 4:16 pm)
[patch 21/47] x86: Sanitize apb timer interrupt handling, Thomas Gleixner, (Thu Sep 30, 4:16 pm)
[patch 22/47] x86: lguest: Convert to new irq chip functions, Thomas Gleixner, (Thu Sep 30, 4:16 pm)
[patch 23/47] x86: Cleanup visws interrupt handling, Thomas Gleixner, (Thu Sep 30, 4:16 pm)
[patch 24/47] x86: i8259: Convert to new irq_chip functions, Thomas Gleixner, (Thu Sep 30, 4:16 pm)
[patch 25/47] x86: Cleanup io_apic, Thomas Gleixner, (Thu Sep 30, 4:16 pm)
[patch 29/47] pci: Convert msi to new irq_chip functions, Thomas Gleixner, (Thu Sep 30, 4:16 pm)
[patch 30/47] dmar: Convert to new irq chip functions, Thomas Gleixner, (Thu Sep 30, 4:16 pm)
[patch 31/47] ht: Convert to new irq_chip functions, Thomas Gleixner, (Thu Sep 30, 4:17 pm)
[patch 32/47] x86: ioapic: Clean up the direct access to i ..., Thomas Gleixner, (Thu Sep 30, 4:17 pm)
[patch 33/47] pci: Cleanup the irq_desc mess in msi, Thomas Gleixner, (Thu Sep 30, 4:17 pm)
[patch 35/47] x86: ioapic: Cleanup some more, Thomas Gleixner, (Thu Sep 30, 4:17 pm)
[patch 36/47] x86: ioapic: Cleanup sparse irq code, Thomas Gleixner, (Thu Sep 30, 4:17 pm)
[patch 38/47] x86: Use sane enumeration, Thomas Gleixner, (Thu Sep 30, 4:17 pm)
[patch 39/47] genirq: Remove arch_init_chip_data(), Thomas Gleixner, (Thu Sep 30, 4:17 pm)
[patch 40/47] genirq: Sanitize dynamic irq handling, Thomas Gleixner, (Thu Sep 30, 4:17 pm)
[patch 41/47] arm: davinci: Cleanup irq_desc access, Thomas Gleixner, (Thu Sep 30, 4:18 pm)
[patch 43/47] x86: xen: Sanitise sparse_irq handling, Thomas Gleixner, (Thu Sep 30, 4:18 pm)
[patch 44/47] sh: Sanitize sparse irq, Thomas Gleixner, (Thu Sep 30, 4:18 pm)
[patch 45/47] x86: lguest: Use new irq allocator, Thomas Gleixner, (Thu Sep 30, 4:18 pm)
[patch 46/47] powerpc: Use new irq allocator, Thomas Gleixner, (Thu Sep 30, 4:18 pm)
Re: [patch 46/47] powerpc: Use new irq allocator, Benjamin Herrenschmidt, (Thu Sep 30, 5:42 pm)
Re: [patch 00/47] Sparse irq rework, Linus Torvalds, (Thu Sep 30, 8:32 pm)
Re: [patch 00/47] Sparse irq rework, Yinghai Lu, (Thu Sep 30, 10:54 pm)
Re: [patch 46/47] powerpc: Use new irq allocator, Thomas Gleixner, (Fri Oct 1, 6:07 am)
Re: [patch 00/47] Sparse irq rework, Thomas Gleixner, (Fri Oct 1, 1:35 pm)
Re: [patch 46/47] powerpc: Use new irq allocator, Benjamin Herrenschmidt, (Fri Oct 1, 1:46 pm)
Re: [patch 46/47] powerpc: Use new irq allocator, Grant Likely, (Fri Oct 1, 2:11 pm)
Re: [patch 46/47] powerpc: Use new irq allocator, Benjamin Herrenschmidt, (Fri Oct 1, 2:17 pm)
Re: [patch 16/47] genirq: Implement sane enumeration, Grant Likely, (Sun Oct 3, 3:55 am)
Re: [patch 00/47] Sparse irq rework, Grant Likely, (Sun Oct 3, 4:23 am)
Re: [patch 00/47] Sparse irq rework, Russell King - ARM Linux, (Sun Oct 3, 4:29 am)
Re: [patch 00/47] Sparse irq rework, Grant Likely, (Sun Oct 3, 4:57 am)
Re: [patch 00/47] Sparse irq rework, Thomas Gleixner, (Sun Oct 3, 6:48 am)
Re: [patch 20/47] x86: Remove useless reinitialization of ..., Eric W. Biederman, (Sun Oct 3, 8:21 am)
Re: [patch 00/47] Sparse irq rework, Eric W. Biederman, (Sun Oct 3, 9:41 am)
Re: [patch 46/47] powerpc: Use new irq allocator, Eric W. Biederman, (Sun Oct 3, 9:53 am)
Re: [patch 46/47] powerpc: Use new irq allocator, Thomas Gleixner, (Sun Oct 3, 11:34 am)
Re: [patch 00/47] Sparse irq rework, Thomas Gleixner, (Sun Oct 3, 12:16 pm)
Re: [patch 46/47] powerpc: Use new irq allocator, Thomas Gleixner, (Sun Oct 3, 1:04 pm)
Re: [patch 46/47] powerpc: Use new irq allocator, Benjamin Herrenschmidt, (Sun Oct 3, 3:54 pm)
Re: [patch 00/47] Sparse irq rework, Benjamin Herrenschmidt, (Sun Oct 3, 3:57 pm)
Re: [patch 46/47] powerpc: Use new irq allocator, Eric W. Biederman, (Sun Oct 3, 5:15 pm)
Re: [patch 46/47] powerpc: Use new irq allocator, Benjamin Herrenschmidt, (Sun Oct 3, 5:37 pm)
Re: [patch 00/47] Sparse irq rework, Eric W. Biederman, (Sun Oct 3, 5:49 pm)
Re: [patch 00/47] Sparse irq rework, Eric W. Biederman, (Sun Oct 3, 6:13 pm)
Re: [patch 00/47] Sparse irq rework, Ingo Molnar, (Sun Oct 3, 11:36 pm)
Re: [patch 00/47] Sparse irq rework, Thomas Gleixner, (Mon Oct 4, 1:05 am)
Re: [patch 00/47] Sparse irq rework, Grant Likely, (Mon Oct 4, 9:31 am)
Re: [patch 46/47] powerpc: Use new irq allocator, Grant Likely, (Mon Oct 4, 9:46 am)
Re: [patch 00/47] Sparse irq rework, Thomas Gleixner, (Tue Oct 5, 3:22 am)
Re: [patch 00/47] Sparse irq rework, Yinghai Lu, (Wed Oct 6, 3:45 pm)
Re: [patch 00/47] Sparse irq rework, Thomas Gleixner, (Wed Oct 6, 3:52 pm)
Re: [patch 00/47] Sparse irq rework, Yinghai Lu, (Wed Oct 6, 4:37 pm)
Re: [patch 00/47] Sparse irq rework, Yinghai Lu, (Wed Oct 6, 5:16 pm)
Re: [patch 00/47] Sparse irq rework, Thomas Gleixner, (Wed Oct 6, 9:01 pm)
Re: [patch 00/47] Sparse irq rework, Yinghai Lu, (Wed Oct 6, 9:38 pm)
Re: [patch 00/47] Sparse irq rework, Thomas Gleixner, (Fri Oct 8, 2:50 pm)
Re: [patch 00/47] Sparse irq rework, Thomas Gleixner, (Fri Oct 8, 2:54 pm)
Re: [patch 00/47] Sparse irq rework, Yinghai Lu, (Fri Oct 8, 9:26 pm)
Re: [patch 00/47] Sparse irq rework, Yinghai Lu, (Fri Oct 8, 10:44 pm)
Re: [patch 00/47] Sparse irq rework, Thomas Gleixner, (Fri Oct 8, 11:10 pm)
Re: [patch 00/47] Sparse irq rework, Thomas Gleixner, (Fri Oct 8, 11:34 pm)
Re: [patch 00/47] Sparse irq rework, Yinghai Lu, (Sat Oct 9, 12:03 am)
Re: [patch 00/47] Sparse irq rework, Yinghai Lu, (Sat Oct 9, 12:08 am)
Re: [patch 00/47] Sparse irq rework, Thomas Gleixner, (Sat Oct 9, 5:08 am)
Re: [patch 00/47] Sparse irq rework, Thomas Gleixner, (Sat Oct 9, 5:12 am)
Re: [patch 00/47] Sparse irq rework, Yinghai Lu, (Sat Oct 9, 7:32 pm)
Re: [patch 00/47] Sparse irq rework, Yinghai Lu, (Sat Oct 9, 10:11 pm)
Re: [patch 00/47] Sparse irq rework, Thomas Gleixner, (Sun Oct 10, 1:20 am)
Re: [patch 00/47] Sparse irq rework, Thomas Gleixner, (Sun Oct 10, 2:32 am)
Re: [patch 00/47] Sparse irq rework, Anca Emanuel, (Sun Oct 10, 6:30 am)
Re: [patch 00/47] Sparse irq rework, Yinghai Lu, (Sun Oct 10, 7:20 pm)
Re: [patch 00/47] Sparse irq rework, Yinghai Lu, (Sun Oct 10, 8:50 pm)
Re: [patch 00/47] Sparse irq rework, Thomas Gleixner, (Mon Oct 11, 1:16 am)
Re: [patch 00/47] Sparse irq rework, Benjamin Herrenschmidt, (Mon Oct 11, 4:34 am)
Re: [patch 00/47] Sparse irq rework, Yinghai Lu, (Mon Oct 11, 9:19 am)
Re: [patch 33/47] pci: Cleanup the irq_desc mess in msi, Jesse Barnes, (Mon Oct 11, 10:08 am)
[tip:irq/core] x86: Don't setup ioapic irq for sci twice, tip-bot for Yinghai Lu, (Tue Oct 12, 1:23 pm)